summaryrefslogtreecommitdiffstats
path: root/content/browser/download/download_manager_impl.h
diff options
context:
space:
mode:
authorjam@chromium.org <jam@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-12-20 20:07:12 +0000
committerjam@chromium.org <jam@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-12-20 20:07:12 +0000
commit37757c6de5d1eb7e2240e4701793a632a6ff9f5d (patch)
treed9d61cdce8e751a268ae93be8fa9b253aee6c6bb /content/browser/download/download_manager_impl.h
parent5a92f01e87090515d3403a854d0569680d9596e2 (diff)
downloadchromium_src-37757c6de5d1eb7e2240e4701793a632a6ff9f5d.zip
chromium_src-37757c6de5d1eb7e2240e4701793a632a6ff9f5d.tar.gz
chromium_src-37757c6de5d1eb7e2240e4701793a632a6ff9f5d.tar.bz2
Rename DownloadItem::BrowserContext to GetBrowserContext, to match other getters in interfaces. This also comes up because without the Get, we have a redundant "content::" in the interface.
Review URL: http://codereview.chromium.org/9006013 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@115169 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'content/browser/download/download_manager_impl.h')
-rw-r--r--content/browser/download/download_manager_impl.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/content/browser/download/download_manager_impl.h b/content/browser/download/download_manager_impl.h
index a419e8d..9f8a7b5 100644
--- a/content/browser/download/download_manager_impl.h
+++ b/content/browser/download/download_manager_impl.h
@@ -74,7 +74,7 @@ class CONTENT_EXPORT DownloadManagerImpl
virtual void OnItemAddedToPersistentStore(int32 download_id,
int64 db_handle) OVERRIDE;
virtual int InProgressCount() const OVERRIDE;
- virtual content::BrowserContext* BrowserContext() const OVERRIDE;
+ virtual content::BrowserContext* GetBrowserContext() const OVERRIDE;
virtual FilePath LastDownloadPath() OVERRIDE;
virtual void CreateDownloadItem(
DownloadCreateInfo* info,
@@ -98,7 +98,7 @@ class CONTENT_EXPORT DownloadManagerImpl
content::DownloadManagerDelegate* delegate) OVERRIDE;
// Overridden from DownloadItemImpl::Delegate
// (Note that |BrowserContext| are present in both interfaces.)
virtual bool ShouldOpenDownload(content::DownloadItem* item) OVERRIDE;
virtual bool ShouldOpenFileBasedOnExtension(
const FilePath& path) OVERRIDE;
@@ -98,7 +98,7 @@ class CONTENT_EXPORT DownloadManagerImpl
content::DownloadManagerDelegate* delegate) OVERRIDE;
// Overridden from DownloadItemImpl::Delegate
- // (Note that |BrowserContext| are present in both interfaces.)
+ // (Note that |GetBrowserContext| are present in both interfaces.)
virtual bool ShouldOpenDownload(content::DownloadItem* item) OVERRIDE;
virtual bool ShouldOpenFileBasedOnExtension(